@@ -1,6 +1,12 @@
+# -*- coding: utf-8 -*-
+# pylint: disable-msg=w0108
 '''test stuf'''
 
-import unittest
+from __future__ import absolute_import
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 
 class TestStuf(unittest.TestCase):
@@ -10,8 +16,15 @@ class TestStuf(unittest.TestCase):
         from stuf import stuf
         return stuf
 
+    @property
+    def _maketwo(self):
+        from stuf import istuf
+        return istuf
+
     def setUp(self):
-        self.stuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        self.stuf = self._makeone(
+            test1='test1', test2='test2', test3=dict(e=1)
+        )
 
     def test__getattr__(self):
         self.assertEqual(self.stuf.test1, 'test1')
@@ -47,9 +60,9 @@ class TestStuf(unittest.TestCase):
         del self.stuf.test1
         del self.stuf.test2
         del self.stuf.test3.e
-        self.assertTrue(len(self.stuf.test3)==0)
+        self.assertTrue(len(self.stuf.test3) == 0)
         del self.stuf.test3
-        self.assertTrue(len(self.stuf)==0)
+        self.assertTrue(len(self.stuf) == 0)
         self.assertRaises(AttributeError, lambda: self.stuf.test1)
         self.assertRaises(AttributeError, lambda: self.stuf.test2)
         self.assertRaises(AttributeError, lambda: self.stuf.test3)
@@ -60,9 +73,9 @@ class TestStuf(unittest.TestCase):
         del self.stuf['test2']
         del self.stuf['test3']['e']
         self.assertFalse('e' in self.stuf['test3'])
-        self.assertTrue(len(self.stuf['test3'])==0)
+        self.assertTrue(len(self.stuf['test3']) == 0)
         del self.stuf['test3']
-        self.assertTrue(len(self.stuf)==0)
+        self.assertTrue(len(self.stuf) == 0)
         self.assertFalse('test1' in self.stuf)
         self.assertFalse('test2' in self.stuf)
         self.assertFalse('test3' in self.stuf)
@@ -75,7 +88,7 @@ class TestStuf(unittest.TestCase):
         self.assertIsNone(self.stuf.get('test3').get('r'))
 
     def test__cmp__(self):
-        tstuff = self._makeone(
+        tstuff = self._maketwo(
             (('test1', 'test1'), ('test2', 'test2'), ('test3', dict(e=1)))
         )
         self.assertEqual(self.stuf, tstuff)
@@ -140,7 +153,7 @@ class TestStuf(unittest.TestCase):
         tstuff['test2'] = 6
         tstuff['test3'] = dict(f=2)
         self.stuf.update(tstuff)
-        self.assertEqual(self.stuf['test1'], 3)
+        self.assertEqual(self.stuf['test1'], 3, self.stuf.items())
         self.assertEqual(self.stuf['test2'], 6)
         self.assertEqual(self.stuf['test3'], dict(f=2), self.stuf)
 
@@ -160,6 +173,18 @@ class TestStuf(unittest.TestCase):
         self.assertTrue('test2' in slist2)
         self.assertTrue('test3' in slist2)
 
+    def test_pickle(self):
+        import pickle
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        pkle = pickle.dumps(tstuf)
+        nstuf = pickle.loads(pkle)
+        self.assertEquals(tstuf, nstuf)
+
+    def test_copy(self):
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        nstuf = tstuf.copy()
+        self.assertEquals(tstuf, nstuf)
+
 
 class TestDefaultStuf(unittest.TestCase):
 
@@ -168,24 +193,29 @@ class TestDefaultStuf(unittest.TestCase):
         from stuf import defaultstuf
         return defaultstuf
 
+    @property
+    def _maketwo(self):
+        from stuf import idefaultstuf
+        return idefaultstuf
+
     def setUp(self):
         self.stuf = self._makeone(
-            list, ([1, 2],), test1='test1', test2='test2', test3=dict(e=1)
+            list, test1='test1', test2='test2', test3=dict(e=1)
         )
 
     def test__getattr__(self):
         self.assertEqual(self.stuf.test1, 'test1')
         self.assertEqual(self.stuf.test2, 'test2')
-        self.assertEqual(self.stuf.test4, [1, 2])
+        self.assertEqual(self.stuf.test4, [])
         self.assertEqual(self.stuf.test3.e, 1)
-        self.assertEqual(self.stuf.test3.f, [1, 2])
+        self.assertEqual(self.stuf.test3.f, [])
 
     def test__getitem__(self):
         self.assertEqual(self.stuf['test1'], 'test1')
         self.assertEqual(self.stuf['test2'], 'test2')
-        self.assertEqual(self.stuf['test4'], [1, 2])
+        self.assertEqual(self.stuf['test4'], [])
         self.assertEqual(self.stuf['test3']['e'], 1)
-        self.assertEqual(self.stuf['test3']['f'], [1, 2])
+        self.assertEqual(self.stuf['test3']['f'], [])
 
     def test__setattr__(self):
         self.stuf.max = 3
@@ -211,12 +241,12 @@ class TestDefaultStuf(unittest.TestCase):
         del self.stuf.test1
         del self.stuf.test2
         del self.stuf.test3.e
-        self.assertTrue(len(self.stuf.test3)==0)
+        self.assertTrue(len(self.stuf.test3) == 0)
         del self.stuf.test3
-        self.assertTrue(len(self.stuf)==0)
-        self.assertEqual(self.stuf.test1, [1, 2])
-        self.assertEqual(self.stuf.test2, [1, 2])
-        self.assertEqual(self.stuf.test3, [1, 2])
+        self.assertTrue(len(self.stuf) == 0)
+        self.assertEqual(self.stuf.test1, [])
+        self.assertEqual(self.stuf.test2, [])
+        self.assertEqual(self.stuf.test3, [])
         self.assertRaises(AttributeError, lambda: self.stuf.test3.e)
 
     def test__delitem__(self):
@@ -224,16 +254,16 @@ class TestDefaultStuf(unittest.TestCase):
         del self.stuf['test2']
         del self.stuf['test3']['e']
         self.assertFalse('e' in self.stuf['test3'])
-        self.assertTrue(len(self.stuf['test3'])==0)
-        self.assertEqual(self.stuf['test3']['e'], [1, 2])
+        self.assertTrue(len(self.stuf['test3']) == 0)
+        self.assertEqual(self.stuf['test3']['e'], [])
         del self.stuf['test3']
-        self.assertTrue(len(self.stuf)==0)
+        self.assertTrue(len(self.stuf) == 0)
         self.assertFalse('test1' in self.stuf)
         self.assertFalse('test2' in self.stuf)
         self.assertFalse('test3' in self.stuf)
-        self.assertEqual(self.stuf['test1'], [1, 2])
-        self.assertEqual(self.stuf['test2'], [1, 2])
-        self.assertEqual(self.stuf['test3'], [1, 2])
+        self.assertEqual(self.stuf['test1'], [])
+        self.assertEqual(self.stuf['test2'], [])
+        self.assertEqual(self.stuf['test3'], [])
         self.assertRaises(TypeError, lambda: self.stuf['test3']['e'])
 
     def test_get(self):
@@ -244,10 +274,11 @@ class TestDefaultStuf(unittest.TestCase):
         self.assertIsNone(self.stuf.get('test3').get('r'))
 
     def test__cmp__(self):
-        tstuff = self._makeone(
+        tstuff = self._maketwo(
             list,
             (1, 2),
-            (('test1', 'test1'), ('test2', 'test2'), ('test3', dict(e=1)))
+            {},
+            (('test1', 'test1'), ('test2', 'test2'), ('test3', dict(e=1))),
         )
         self.assertEqual(self.stuf, tstuff)
 
@@ -258,20 +289,20 @@ class TestDefaultStuf(unittest.TestCase):
     def test_clear(self):
         self.stuf.test3.clear()
         self.assertEqual(len(self.stuf.test3), 0)
-        self.assertEqual(self.stuf['test3']['e'], [1, 2])
+        self.assertEqual(self.stuf['test3']['e'], [])
         self.stuf.clear()
         self.assertEqual(len(self.stuf), 0)
-        self.assertEqual(self.stuf['test1'], [1, 2])
-        self.assertEqual(self.stuf['test2'], [1, 2])
-        self.assertEqual(self.stuf['test3'], [1, 2])
+        self.assertEqual(self.stuf['test1'], [])
+        self.assertEqual(self.stuf['test2'], [])
+        self.assertEqual(self.stuf['test3'], [])
 
     def test_items(self):
-        self.assertEqual(self.stuf['test4'], [1, 2])
+        self.assertEqual(self.stuf['test4'], [])
         slist = list(self.stuf.items())
         self.assertTrue(('test1', 'test1') in slist)
         self.assertTrue(('test2', 'test2') in slist)
         self.assertTrue(('test3', {'e': 1}) in slist)
-        self.assertTrue(('test4', [1, 2]) in slist)
+        self.assertTrue(('test4', []) in slist)
 
     def test_iteritems(self):
         slist = list(self.stuf.iteritems())
@@ -339,6 +370,22 @@ class TestDefaultStuf(unittest.TestCase):
         self.assertTrue('test2' in slist2)
         self.assertTrue('test3' in slist2)
 
+    def test_pickle(self):
+        import pickle
+        tstuf = self._makeone(
+            list, ([],), test1='test1', test2='test2', test3=dict(e=1)
+        )
+        pkle = pickle.dumps(tstuf)
+        nstuf = pickle.loads(pkle)
+        self.assertEquals(tstuf, nstuf)
+
+    def test_copy(self):
+        tstuf = self._makeone(
+            list, ([],), test1='test1', test2='test2', test3=dict(e=1)
+        )
+        nstuf = tstuf.copy()
+        self.assertEquals(tstuf, nstuf)
+
 
 class TestFixedStuf(unittest.TestCase):
 
@@ -347,6 +394,11 @@ class TestFixedStuf(unittest.TestCase):
         from stuf import fixedstuf
         return fixedstuf
 
+    @property
+    def _maketwo(self):
+        from stuf import ifixedstuf
+        return ifixedstuf
+
     def setUp(self):
         self.stuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
 
@@ -385,8 +437,10 @@ class TestFixedStuf(unittest.TestCase):
         self.assertRaises(TypeError, lambda: delattr(self.stuf.test3.e))
 
     def test__delitem__(self):
-        self.assertRaises(AttributeError, lambda: self.stuf.__delitem__('test1'))
-        self.assertRaises(AttributeError, lambda: self.stuf.test3.__delitem__('test1'))
+        del self.stuf['test1']
+        self.assertIsNone(self.stuf['test1'])
+        del self.stuf.test3['test1']
+        self.assertIsNone(self.stuf.test3['test1'])
 
     def test_get(self):
         self.assertEqual(self.stuf.get('test1'), 'test1')
@@ -396,7 +450,7 @@ class TestFixedStuf(unittest.TestCase):
         self.assertIsNone(self.stuf.get('test3').get('r'))
 
     def test__cmp__(self):
-        tstuff = self._makeone(
+        tstuff = self._maketwo(
             (('test1', 'test1'), ('test2', 'test2'), ('test3', dict(e=1)))
         )
         self.assertEqual(self.stuf, tstuff)
@@ -406,20 +460,24 @@ class TestFixedStuf(unittest.TestCase):
         self.assertEqual(len(self.stuf.test3), 1)
 
     def test_clear(self):
-        self.assertRaises(AttributeError, lambda: self.stuf.test3.clear())
-        self.assertRaises(AttributeError, lambda: self.stuf.clear())
+        self.assertRaises(KeyError, lambda: self.stuf.__setitem__('max', 3))
+        self.stuf.clear()
+        self.stuf['test1'] = 'test1again'
+        self.stuf['test3'] = 5
+
 
     def test_items(self):
         slist = list(self.stuf.items())
         self.assertTrue(('test1', 'test1') in slist)
         self.assertTrue(('test2', 'test2') in slist)
-        self.assertTrue(('test3', {'e': 1}) in slist)
+        dummy = self._maketwo({'e': 1})
+        self.assertTrue(('test3', dummy) in slist, slist)
 
     def test_iteritems(self):
         slist = list(self.stuf.iteritems())
         self.assertTrue(('test1', 'test1') in slist)
         self.assertTrue(('test2', 'test2') in slist)
-        self.assertTrue(('test3', {'e': 1}) in slist)
+        self.assertTrue(('test3', self._maketwo({'e': 1})) in slist, slist)
 
     def test_iterkeys(self):
         slist = list(self.stuf.iterkeys())
@@ -434,7 +492,7 @@ class TestFixedStuf(unittest.TestCase):
         slist2 = list(i for i in self.stuf.test3.itervalues())
         self.assertTrue(1 in slist2)
         self.assertTrue('test1' in slist1)
-        self.assertTrue({'e': 1} in slist1)
+        self.assertTrue(self._maketwo({'e': 1}) in slist1)
         self.assertTrue('test2' in slist1)
 
     def test_pop(self):
@@ -447,9 +505,9 @@ class TestFixedStuf(unittest.TestCase):
 
     def test_setdefault(self):
         self.assertEqual(self.stuf.test3.setdefault('e', 8), 1)
-        self.assertEqual(self.stuf.test3.setdefault('r', 8), 8)
+        self.assertRaises(KeyError, lambda: self.stuf.test3.setdefault('r', 8))
         self.assertEqual(self.stuf.setdefault('test1', 8), 'test1')
-        self.assertEqual(self.stuf.setdefault('pow', 8), 8)
+        self.assertRaises(KeyError, lambda: self.stuf.setdefault('pow', 8))
 
     def test_update(self):
         tstuff = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
@@ -459,7 +517,7 @@ class TestFixedStuf(unittest.TestCase):
         self.stuf.update(tstuff)
         self.assertEqual(self.stuf['test1'], 3)
         self.assertEqual(self.stuf['test2'], 6)
-        self.assertEqual(self.stuf['test3'], dict(f=2), self.stuf)
+        self.assertEqual(self.stuf['test3'], self._maketwo(dict(f=2)), self.stuf['test3'])
 
     def test_values(self):
         slist1 = self.stuf.test3.values()
@@ -467,7 +525,7 @@ class TestFixedStuf(unittest.TestCase):
         self.assertTrue(1 in slist1)
         self.assertTrue('test1' in slist2)
         self.assertTrue('test2' in slist2)
-        self.assertTrue({'e': 1} in slist2)
+        self.assertTrue(self._maketwo({'e': 1}) in slist2)
 
     def test_keys(self):
         slist1 = self.stuf.test3.keys()
@@ -477,6 +535,17 @@ class TestFixedStuf(unittest.TestCase):
         self.assertTrue('test2' in slist2)
         self.assertTrue('test3' in slist2)
 
+    def test_copy(self):
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        nstuf = tstuf.copy()
+        self.assertEquals(tstuf, nstuf)
+
+    def test_pickle(self):
+        import pickle
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        pkle = pickle.dumps(tstuf)
+        nstuf = pickle.loads(pkle)
+        self.assertEquals(tstuf, nstuf)
 
 
 class TestFrozenStuf(unittest.TestCase):
@@ -486,6 +555,11 @@ class TestFrozenStuf(unittest.TestCase):
         from stuf import frozenstuf
         return frozenstuf
 
+    @property
+    def _maketwo(self):
+        from stuf import ifrozenstuf
+        return ifrozenstuf
+
     def setUp(self):
         self.stuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
 
@@ -500,11 +574,13 @@ class TestFrozenStuf(unittest.TestCase):
         self.assertEqual(self.stuf['test3']['e'], 1)
 
     def test__setattr__(self):
-        self.assertRaises(TypeError, lambda: setattr(self.stuf, 'max', 3))
+        self.assertRaises(AttributeError, setattr(self.stuf, 'max', 3))
         self.assertRaises(
-            TypeError, lambda: setattr(self.stuf, 'test1', 'test1again')
+            AttributeError, setattr(self.stuf, 'test1', 'test1again')
+        )
+        self.assertRaises(
+            AttributeError, setattr(self.stuf.test3, 'e', 5)
         )
-        self.assertRaises(TypeError, lambda: setattr(self.stuf.test3, 'e', 5))
 
     def test__setitem__(self):
         self.assertRaises(
@@ -522,8 +598,12 @@ class TestFrozenStuf(unittest.TestCase):
         self.assertRaises(TypeError, lambda: delattr(self.stuf.test3.e))
 
     def test__delitem__(self):
-        self.assertRaises(AttributeError, lambda: self.stuf.__delitem__('test1'))
-        self.assertRaises(AttributeError, lambda: self.stuf.test3.__delitem__('test1'))
+        self.assertRaises(
+            AttributeError, lambda: self.stuf.__delitem__('test1'),
+        )
+        self.assertRaises(
+            AttributeError, lambda: self.stuf.test3.__delitem__('test1'),
+        )
 
     def test_get(self):
         self.assertEqual(self.stuf.get('test1'), 'test1')
@@ -533,7 +613,7 @@ class TestFrozenStuf(unittest.TestCase):
         self.assertIsNone(self.stuf.get('test3').get('r'))
 
     def test__cmp__(self):
-        tstuff = self._makeone(
+        tstuff = self._maketwo(
             (('test1', 'test1'), ('test2', 'test2'), ('test3', dict(e=1)))
         )
         self.assertEqual(self.stuf, tstuff)
@@ -550,13 +630,13 @@ class TestFrozenStuf(unittest.TestCase):
         slist = list(self.stuf.items())
         self.assertTrue(('test1', 'test1') in slist)
         self.assertTrue(('test2', 'test2') in slist)
-        self.assertTrue(('test3', {'e': 1}) in slist)
+        self.assertTrue(('test3', self._maketwo({'e': 1})) in slist, slist)
 
     def test_iteritems(self):
         slist = list(self.stuf.iteritems())
         self.assertTrue(('test1', 'test1') in slist)
         self.assertTrue(('test2', 'test2') in slist)
-        self.assertTrue(('test3', {'e': 1}) in slist)
+        self.assertTrue(('test3', self._maketwo({'e': 1})) in slist, slist)
 
     def test_iterkeys(self):
         slist = list(self.stuf.iterkeys())
@@ -570,7 +650,7 @@ class TestFrozenStuf(unittest.TestCase):
         slist1 = list(self.stuf.itervalues())
         slist2 = list(self.stuf.test3.itervalues())
         self.assertTrue('test2' in slist1)
-        self.assertTrue({'e': 1} in slist1)
+        self.assertTrue(self._maketwo({'e': 1}) in slist1)
         self.assertTrue(1 in slist2)
         self.assertTrue('test1' in slist1)
 
@@ -583,21 +663,31 @@ class TestFrozenStuf(unittest.TestCase):
         self.assertRaises(AttributeError, lambda: self.stuf.popitem())
 
     def test_setdefault(self):
-        self.assertEqual(self.stuf.test3.setdefault('e', 8), 1)
-        self.assertEqual(self.stuf.test3.setdefault('r', 8), 8)
-        self.assertEqual(self.stuf.setdefault('test1', 8), 'test1')
-        self.assertEqual(self.stuf.setdefault('pow', 8), 8)
+        self.assertRaises(
+            AttributeError, lambda: self.stuf.test3.setdefault('e', 8)
+        )
+        self.assertRaises(
+            AttributeError, lambda: self.stuf.test3.setdefault('r', 8)
+        )
+        self.assertRaises(
+            AttributeError, lambda: self.stuf.setdefault('test1', 8)
+        )
+        self.assertRaises(
+            AttributeError, lambda:self.stuf.setdefault('pow', 8)
+        )
 
     def test_update(self):
         tstuff = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
-        self.assertRaises(AttributeError, lambda: self.stuf.test3.update(tstuff))
+        self.assertRaises(
+            AttributeError, lambda: self.stuf.test3.update(tstuff),
+        )
         self.assertRaises(AttributeError, lambda: self.stuf.update(tstuff))
 
     def test_values(self):
         slist1 = self.stuf.test3.values()
         slist2 = self.stuf.values()
         self.assertTrue(1 in slist1)
-        self.assertTrue({'e': 1} in slist2)
+        self.assertTrue(self._maketwo({'e': 1}) in slist2)
         self.assertTrue('test2' in slist2)
         self.assertTrue('test1' in slist2)
 
@@ -609,6 +699,18 @@ class TestFrozenStuf(unittest.TestCase):
         self.assertTrue('test2' in slist2)
         self.assertTrue('test3' in slist2)
 
+    def test_copy(self):
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        nstuf = tstuf.copy()
+        self.assertEquals(tstuf, nstuf)
+
+    def test_pickle(self):
+        import pickle
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        pkle = pickle.dumps(tstuf)
+        nstuf = pickle.loads(pkle)
+        self.assertEquals(tstuf, nstuf)
+
 
 class TestOrderedStuf(unittest.TestCase):
 
@@ -617,6 +719,11 @@ class TestOrderedStuf(unittest.TestCase):
         from stuf import orderedstuf
         return orderedstuf
 
+    @property
+    def _maketwo(self):
+        from stuf import iorderedstuf
+        return iorderedstuf
+
     def setUp(self):
         self.stuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
 
@@ -654,9 +761,9 @@ class TestOrderedStuf(unittest.TestCase):
         del self.stuf.test1
         del self.stuf.test2
         del self.stuf.test3.e
-        self.assertTrue(len(self.stuf.test3)==0)
+        self.assertTrue(len(self.stuf.test3) == 0)
         del self.stuf.test3
-        self.assertTrue(len(self.stuf)==0)
+        self.assertTrue(len(self.stuf) == 0)
         self.assertRaises(AttributeError, lambda: self.stuf.test1)
         self.assertRaises(AttributeError, lambda: self.stuf.test2)
         self.assertRaises(AttributeError, lambda: self.stuf.test3)
@@ -667,9 +774,9 @@ class TestOrderedStuf(unittest.TestCase):
         del self.stuf['test2']
         del self.stuf['test3']['e']
         self.assertFalse('e' in self.stuf['test3'])
-        self.assertTrue(len(self.stuf['test3'])==0)
+        self.assertTrue(len(self.stuf['test3']) == 0)
         del self.stuf['test3']
-        self.assertTrue(len(self.stuf)==0)
+        self.assertTrue(len(self.stuf) == 0)
         self.assertFalse('test1' in self.stuf)
         self.assertFalse('test2' in self.stuf)
         self.assertFalse('test3' in self.stuf)
@@ -682,7 +789,7 @@ class TestOrderedStuf(unittest.TestCase):
         self.assertIsNone(self.stuf.get('test3').get('r'))
 
     def test__cmp__(self):
-        tstuff = self._makeone(
+        tstuff = self._maketwo(
             (('test1', 'test1'), ('test2', 'test2'), ('test3', dict(e=1)))
         )
         self.assertEqual(self.stuf, tstuff)
@@ -707,7 +814,7 @@ class TestOrderedStuf(unittest.TestCase):
         slist = list(self.stuf.iteritems())
         self.assertTrue(('test1', 'test1') in slist)
         self.assertTrue(('test2', 'test2') in slist)
-        self.assertTrue(('test3', {'e': 1}) in slist)
+        self.assertTrue(('test3', self._maketwo({'e': 1})) in slist)
 
     def test_iterkeys(self):
         slist = list(self.stuf.iterkeys())
@@ -722,7 +829,7 @@ class TestOrderedStuf(unittest.TestCase):
         slist2 = list(self.stuf.test3.itervalues())
         self.assertTrue('test1' in slist)
         self.assertTrue('test2' in slist)
-        self.assertTrue({'e': 1} in slist)
+        self.assertTrue(self._maketwo({'e': 1}) in slist)
         self.assertTrue(1 in slist2)
 
     def test_pop(self):
@@ -757,7 +864,7 @@ class TestOrderedStuf(unittest.TestCase):
         self.assertTrue(1 in slist1)
         self.assertTrue('test1' in slist2)
         self.assertTrue('test2' in slist2)
-        self.assertTrue({'e': 1} in slist2)
+        self.assertTrue(self._maketwo({'e': 1}) in slist2)
 
     def test_keys(self):
         slist1 = self.stuf.test3.keys()
@@ -767,5 +874,17 @@ class TestOrderedStuf(unittest.TestCase):
         self.assertTrue('test2' in slist2)
         self.assertTrue('test3' in slist2)
 
+    def test_copy(self):
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        nstuf = tstuf.copy()
+        self.assertEquals(tstuf, nstuf)
 
-if __name__ == '__main__': unittest.main()
\ No newline at end of file
+    def test_pickle(self):
+        import pickle
+        tstuf = self._makeone(test1='test1', test2='test2', test3=dict(e=1))
+        pkle = pickle.dumps(tstuf)
+        nstuf = pickle.loads(pkle)
+        self.assertEquals(tstuf, nstuf)
+
+if __name__ == '__main__': 
+    unittest.main()
